@@ -110,6 +110,9 @@ INVALIDPARAMETER_BIZAPPROVERALREADYEXISTS = 'InvalidParameter.BizApproverAlready
 # 营业执照格式不合法。
 INVALIDPARAMETER_BUSINESSLICENSE = 'InvalidParameter.BusinessLicense'
 
+# 撤销理由填写格式错误。
+INVALIDPARAMETER_CANCELREASON = 'InvalidParameter.CancelReason'
+
 # 证件类型错误。
 INVALIDPARAMETER_CARDTYPE = 'InvalidParameter.CardType'
 
@@ -131,6 +134,9 @@ INVALIDPARAMETER_DATANOTFOUND = 'InvalidParameter.DataNotFound'
 # 参数错误，不合法的日期，请检查后重试。
 INVALIDPARAMETER_DATE = 'InvalidParameter.Date'
 
+# 员工ID不正确。
+INVALIDPARAMETER_DEPARTUSERID = 'InvalidParameter.DepartUserId'
+
 # 重复提交任务。
 INVALIDPARAMETER_DUPTASK = 'InvalidParameter.DupTask'
 
@@ -320,6 +326,9 @@ OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
 # 流程已终止。
 OPERATIONDENIED_FLOWHASTERMINATED = 'OperationDenied.FlowHasTerminated'
 
+# 签署流程状态不正确，请检查后重试。
+OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'
+
 # 禁止操作。
 OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 
@@ -329,21 +338,33 @@ OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
 # 没有API权限。
 OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
 
+# 无权操作合同。
+OPERATIONDENIED_NOFLOWPERMISSION = 'OperationDenied.NoFlowPermission'
+
 # 未通过个人实名。
 OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'
 
 # 流程配额不足。
 OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'
 
+# 不属于企业超管或者法人。
+OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
+
 # 操作类型不支持。
 OPERATIONDENIED_OPERATETYPE = 'OperationDenied.OperateType'
 
+# 操作者权限不足。
+OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermission'
+
 # 超出查询上限。
 OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'
 
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
+# 未开通功能白名单，请联系客服处理。
+OPERATIONDENIED_WHITELISTFORBID = 'OperationDenied.WhiteListForbid'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -362,6 +383,9 @@ RESOURCENOTFOUND_FILE = 'ResourceNotFound.File'
 # 未找到对应流程。
 RESOURCENOTFOUND_FLOW = 'ResourceNotFound.Flow'
 
+# 签署流程的签署人不存在，请检查后重试。
+RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'
+
 # 签署人信息不存在，请检查后重试。
 RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 
@@ -380,6 +404,9 @@ RESOURCENOTFOUND_TEAMWORKORGANIZATION = 'ResourceNotFound.TeamWorkOrganization'
 # 模板不存在。
 RESOURCENOTFOUND_TEMPLATE = 'ResourceNotFound.Template'
 
+# Url不存在。
+RESOURCENOTFOUND_URL = 'ResourceNotFound.URL'
+
 # 用户信息不存在。
 RESOURCENOTFOUND_USER = 'ResourceNotFound.User'
 
@@ -392,6 +419,12 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 未授权下载权限。
+UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONDOWNLOAD = 'UnauthorizedOperation.UnauthorizedOperationDownload'
+
+# 企业没有被授权。
+UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONORGANIZATION = 'UnauthorizedOperation.UnauthorizedOperationOrganization'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
